# Neglect  

## Execution formate
- neglect( file_name.py )

## Functionalities of the Neglect
- Ignores logical program errors
- Helps to run python file by avoiding compilation of mistaken lines 
- indicates error lines inside the program/code itself
- minimise unnecessary usage of try & except 

## Usage
- Make sure you have installed Python in your system.
- Run Following command in the CMD.
  ```
    pip install neglect
  ```
  